---
name: Feature request
about: Feature or functionality request for the 'illumio' library
---

<!-- Feature overview -->

## Use case  

<!-- Describe how the feature will be used and by whom -->

## Example  

<!-- Pseudocode showing how the feature or function would be used -->

```python
import illumio

```
